#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-CxCyWCLDxuYJr2LC3iznI4
key:                  postgrest-10.1.0-CxCyWCLDxuYJr2LC3iznI4
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  8b62a03eb64761f4eac63192baf59bb5
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-CxCyWCLDxuYJr2LC3iznI4
depends:
    HTTP-4000.4.1-5E7T60cpr4dHee0oMOAWkI
    Ranged-sets-0.5.0-CsJCepHA4osIm4asdERUnM
    aeson-2.2.2.0-DAWEUfqGTZl4JS91alOoes
    auto-update-0.1.6-3HDS7ND1sO11kiCVQ4X49B base-4.18.2.1
    base64-bytestring-1.2.1.0-IIktoxS9Rl64vymAP7DWJo
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-KRBUDrDZZz8K0kWnqUEh6i
    cassava-0.5.4.1-2vcf8hc36XH1NK5XOZkni5
    configurator-pg-0.2.11-46REridgM5eCF8LHLR06Xr containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-6V3r1qt7KJI6PUCQUFdLMy
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-HsK92AVkOmiGTvuOlbqW9o
    hasql-dynamic-statements-0.3.1.2-JeaX3d2DirpCjhVNTdpZbN
    hasql-notifications-0.2.0.5-BCgGBSCdksH6vh1iNu4Bup
    hasql-pool-0.8.0.2-Kxw5X1gLqJFApxLi6ozdag
    hasql-transaction-1.0.1.2-HRx7p0VIXq24nSoThQFEd4
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-DIRo50xDRxbE4a3m2IKFXS
    insert-ordered-containers-0.2.5.3-4neNY8oiJZQ19ObnTvj771
    interpolatedstring-perl6-1.0.2-5QTzHojsYeM50YOeEyOUIy
    jose-0.10.0.1-GskVtUIYxz86roLsRh7e4j
    lens-5.3.4-6Y9sfkt8OEM3cWxRkkF9y8
    lens-aeson-1.2.3-49bEu301C9pGbI7H4SJBF1 mtl-2.3.1
    network-3.1.4.0-5CNSYfJ9OXEKTDv1UbcApF
    network-uri-2.6.4.2-5H6FsM3EemmJOLKW8jzcT0
    optparse-applicative-0.18.1.0-Cr55vIK1zHQ6Kp2uvAIcad
    parsec-3.1.16.1 protolude-0.3.5-LWy1KC09nQI6ajFQUiV9Zi
    regex-tdfa-1.3.2.5-6WzoC7SgjRyHxrF8NwW4mF
    retry-0.9.3.1-KZ9DTdK0MGg6xXWYrrBvDm
    scientific-0.3.8.1-5xEN5FH7FNLBtMgMgahhk5
    swagger2-2.8.10-LoRXWMSt3AtLsuJqMZ0sUP text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.20.1-BaP0PevI27VLqsaWB0hjeu
    vault-0.3.1.6-Pa2OunH1IvKMgmAh05wUR
    vector-0.13.2.0-CDuZD6JA02PF3ZzyJqHF4G
    wai-3.2.4-G24K6K8Ph5UGm06VtBGtnN
    wai-cors-0.2.7-JeVoCjPqBDnLZpVkrABzhP
    wai-extra-3.1.18-AwOyuxFl6hPFe7FTdHiXmd
    wai-logger-2.5.0-BKAci8ukJ2PAtbtSd5COym
    warp-3.4.0-5lVJuDIzGQpBE0FrTAzCxB

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

